pub trait ClientCallerBlocking: Send {
type Facts: ClientFacts;
// Required method
fn send_req_blocking(&self, task: <Self::Facts as ClientFacts>::Task);
// Provided method
fn get_codec(&self) -> <Self::Facts as ClientFacts>::Codec { ... }
}Expand description
A trait to support sending request task in blocking text, for all router and connection pool implementations
Required Associated Types
type Facts: ClientFacts
Required Methods
fn send_req_blocking(&self, task: <Self::Facts as ClientFacts>::Task)
Provided Methods
fn get_codec(&self) -> <Self::Facts as ClientFacts>::Codec
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".