pub struct FailoverPool<F, P>where
F: ClientFacts,
P: ClientTransport,{ /* private fields */ }Expand description
A pool supports failover to multiple address with bias or round_robin strategy
Supports async and blocking context.
Only retry RpcIntErr that less than RpcIntErr::Method, currently ignore custom error due to complexity of generic. (If you need to custom failover logic, copy the code and impl your own pool.)
Implementations
Sourceimpl<F, P> FailoverPool<F, P>where
F: ClientFacts,
P: ClientTransport,
impl<F, P> FailoverPool<F, P>where
F: ClientFacts,
P: ClientTransport,
Sourcepub fn new<RT: AsyncRuntime + Clone>(
facts: Arc<F>,
rt: &RT,
addrs: Vec<String>,
round_robin: bool,
retry_limit: usize,
pool_channel_size: usize,
) -> Self
pub fn new<RT: AsyncRuntime + Clone>( facts: Arc<F>, rt: &RT, addrs: Vec<String>, round_robin: bool, retry_limit: usize, pool_channel_size: usize, ) -> Self
Initiate the pool with multiple address. When round_robin == true, all address in the pool will be select with equal chanced; When round_robin == false, the first address will always be pick unless error happens.
pub fn update_addrs<RT: AsyncRuntime + Clone>( &self, addrs: Vec<String>, rt: &RT, )