FailoverPool

Struct FailoverPool 

pub struct FailoverPool<F, P>{ /* private fields */ }
A pool supports failover to multiple address with bias or round_robin strategy

Supports async and blocking context.

Only retry RpcIntErr that less than RpcIntErr::Method, currently ignore custom error due to complexity of generic. (If you need to custom failover logic, copy the code and impl your own pool.)

Implementations

Source

impl<F, P> FailoverPool<F, P>

pub fn new( facts: Arc<F>, addrs: Vec<String>, round_robin: bool, retry_limit: usize, pool_channel_size: usize, ) -> Self

Initate the pool with multiple address. When round_robin == true, all address in the pool will be select with equal chanced; When round_robin == false, the first address will always be pick unless error happens.

pub fn update_addrs(&self, addrs: Vec<String>)