ClientCallerBlocking

Trait ClientCallerBlocking 

pub trait ClientCallerBlocking: Send {
    type Facts: ClientFacts;

    // Required method
    fn send_req_blocking(&self, task: <Self::Facts as ClientFacts>::Task);

    // Provided method
    fn get_codec(&self) -> <Self::Facts as ClientFacts>::Codec { ... }
}
A trait to support sending request task in blocking text, for all router and connection pool implementations

Required Associated Types

Required Methods

fn send_req_blocking(&self, task: <Self::Facts as ClientFacts>::Task)

Provided Methods

fn get_codec(&self) -> <Self::Facts as ClientFacts>::Codec

Implementations on Foreign Types

Source

impl<C: ClientCallerBlocking + Send + Sync> ClientCallerBlocking for Arc<C>

Implementors